@@ -72,9 +72,7 @@ autocorr <- function(data, dvar, pvar, mvar,
     dvar = dvar
   )
   class(out) <- c("sc_ac")
-  attr(out, opt("phase")) <- pvar
-  attr(out, opt("mt")) <- mvar
-  attr(out, opt("dv")) <- dvar
+  attributes(out)[opts("phase", "mt", "dv")] <- list(pvar, mvar, dvar)
   out
 }
 
