@@ -4,14 +4,9 @@ export.sc_pet <- function(object,
                           caption = NA, 
                           footnote = NA, 
                           filename = NA,
-                          kable_styling_options = list(), 
-                          kable_options = list(),
                           round = 1,
                           ...) {
   
-  kable_options <- .join_kabel(kable_options)
-  kable_styling_options <- .join_kabel_styling(kable_styling_options)
-  
   if (is.na(caption)) caption <- c("Percent Exceeding the trend")
   
   if (is.na(footnote)) {
@@ -42,8 +37,6 @@ export.sc_pet <- function(object,
   
   table <- .create_table(
     object$PET, 
-    kable_options, 
-    kable_styling_options, 
     caption = caption,
     footnote = footnote,
     ...
