@@ -97,7 +97,6 @@ nap <- function(data, dvar, pvar,
   
   out <- list(nap = nap)
   class(out) <- c("sc_nap")
-  attr(out, opt("phase")) <- pvar
-  attr(out, opt("dv")) <- dvar
+  attributes(out)[opts("phase", "dv")] <- list(pvar, dvar)
   out
 }
