@@ -10,17 +10,17 @@ NULL
 
 
 .note_vars <- function(x) {
-  v <- any(attr(x, .opt$dv) != "values")
-  p <- attr(x, .opt$phase) != "phase"
-  m <- attr(x, .opt$mt) != "mt"
+  v <- any(attr(x, opt("dv")) != "values")
+  p <- attr(x, opt("phase")) != "phase"
+  m <- attr(x, opt("mt")) != "mt"
   if (v || p || m) { 
     cat(
       "\nThe following variables were used in this analysis:\n'", 
-      paste0(attr(x, .opt$dv), collapse = "/ "), 
+      paste0(attr(x, opt("dv")), collapse = "/ "), 
       "' as dependent variable, '", 
-      paste0(attr(x, .opt$phase), collapse = "/ "), 
+      paste0(attr(x, opt("phase")), collapse = "/ "), 
       "' as phase variable, and '", 
-      paste0(attr(x, .opt$mt), collapse = "/ "), 
+      paste0(attr(x, opt("mt")), collapse = "/ "), 
       "' as measurement-time variable.\n", 
       sep = ""
     )
