@@ -14,4 +14,11 @@ rename_phase_duplicates <- function(phase) {
     SIMPLIFY = FALSE, USE.NAMES = FALSE
   ) |> unlist()
   as.factor(new_phase)
-}
\ No newline at end of file
+}
+
+rownames_to_first_column <- function(x, name = "Rownames") {
+  x <- cbind(.rownames = rownames(x), x)
+  rownames(x) <- NULL
+  names(x)[1] <- name
+  x
+}
